/*
 * drivers/char/rtapi/include/screen_display.h
 *     This file is screen display function.
 *
 * Copyright (C) 2011 Renesas Electronics Corporation
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
 
#ifndef __SCREEN_DISPLAY_H__
#define __SCREEN_DISPLAY_H__

/****************************************/
/* Fixed Number				*/
/****************************************/
/* LCD Type */
#define RT_DISPLAY_LCD1 (1)
#define RT_DISPLAY_LCD2 (2)
#define RT_DISPLAY_SDENC (3)

/** Image format */
#define RT_DISPLAY_FORMAT_RGB565		(1)
#define RT_DISPLAY_FORMAT_ARGB8888		(2)
#define RT_DISPLAY_FORMAT_RGB888		(6)
#define RT_DISPLAY_FORMAT_RGBA5551		(9)

/** Refreshment mode */
#define RT_DISPLAY_REFRESH_ON			(1)
#define RT_DISPLAY_REFRESH_OFF			(2)

/** Display Blend type */
#define RT_DISPLAY_BLEND_LCD			(1)
#define RT_DISPLAY_BLEND_VIO			(2)

/** LCD Blend layer */
#define RT_DISPLAY_LAYER_1				(1)
#define RT_DISPLAY_LAYER_2				(2)
#define RT_DISPLAY_LAYER_3				(3)
#define RT_DISPLAY_LAYER_4				(4)

/** LCD Blend mode */
#define	RT_DISPLAY_OUTPUT_ON			(1)
#define	RT_DISPLAY_OUTPUT_OFF			(2)
#define RT_DISPLAY_OUTPUT_MOVIE			(3)

/** Key Color off **/
#define RT_DISPLAY_KEY_COLOR_OFF		(-1)

/** HDMI Output Format */
#define	RT_DISPLAY_720_480P60			(1)
#define	RT_DISPLAY_1280_720P60			(2)
#define	RT_DISPLAY_1920_1080I60			(3)
#define	RT_DISPLAY_1920_1080P24			(4)

/** RT I/F Return code */
#define SMAP_LIB_DISPLAY_OK				(0)
#define SMAP_LIB_DISPLAY_NG				(-1)
#define SMAP_LIB_DISPLAY_PARAERR		(-2)
#define SMAP_LIB_DISPLAY_SEQERR			(-3)

/****************************************/
/* Structure				*/
/****************************************/
typedef struct
{
	void (*notify_display_lcd_blend)
	(
		int                            result,
		unsigned long                  user_data
	);
} screen_disp_new;

typedef struct
{
	unsigned int VCLKCR3; 
	unsigned int MLDHCNR;
	unsigned int MLDHSYNR;
	unsigned int MLDHAJR;
	unsigned int MLDVLNR;
	unsigned int MLDVSYNR;
	unsigned int MLDMT1R;
} screen_disp_lcd_if;

#ifndef _SCREEN_RECT_TYPE_
#define _SCREEN_RECT_TYPE_
typedef struct
{
	unsigned short x;
	unsigned short y;
	unsigned short width;
	unsigned short height;
} screen_rect;
#endif

typedef struct
{
	void*          handle;
	unsigned short output_mode;
	unsigned short key_color;
	unsigned short alpha;
	unsigned short blend_mode;
} screen_disp_param;

typedef struct
{
	void*          handle;
	unsigned short output_mode;
	unsigned short dummy;
	unsigned int   address;
} screen_disp_get_address;

typedef struct
{
	void*            handle;
	unsigned short   output_mode;
	unsigned short   format;
	screen_rect      draw_rect;
	unsigned int     buffer_offset;
} screen_disp_draw;

typedef struct
{
	void*          handle;
	unsigned short output_mode;
} screen_disp_start_lcd;

typedef struct
{
	void*          handle;
	unsigned short output_mode;
} screen_disp_stop_lcd;

typedef struct
{
	void*          handle;
	unsigned short output_mode;
	unsigned short refresh_mode;
} screen_disp_set_lcd_refresh;

typedef struct
{
	void*               handle;
	screen_disp_lcd_if* lcd_if_param;
	screen_disp_lcd_if* lcd_if_param_mask;
} screen_disp_set_lcd_if_param;

typedef struct
{
	void*        handle;
	unsigned int background_color;
} screen_disp_start_sdenc;

typedef struct
{
	void* handle;
} screen_disp_stop_sdenc;

typedef struct
{
	void*          handle;
	unsigned short output_mode;
	unsigned short dummy;
	unsigned int   address;
	unsigned int   size;
} screen_disp_set_address;

typedef struct
{
	void*           handle;
	unsigned short  layer;
	unsigned short  layer_flag;
	unsigned char*  address;
	unsigned long   size;
	void*           apmem_handle;
	screen_rect     rect;
	unsigned short  stride;
	unsigned short  format;
	long            key_color;
	unsigned short  alpha;
	unsigned long   user_data;
} screen_disp_lcd_blend_draw;

typedef struct
{
	void* handle;
} screen_disp_delete;

/****************************************/
/* function				*/
/****************************************/
/* Create handle */
extern void* screen_display_new
(
	screen_disp_new* disp_new
);

/* Set parameters */
extern int screen_display_set_parameters
(
	screen_disp_param* disp_param
);

/* Get address */
extern int screen_display_get_address
(
	screen_disp_get_address* address
);

/* Draw */
extern int screen_display_draw
(
	screen_disp_draw* disp_draw
);

/* Start LCD */
extern int screen_display_start_lcd
(
	screen_disp_start_lcd* start_lcd
);

/* Stop LCD */
extern int screen_display_stop_lcd
(
	screen_disp_stop_lcd* stop_lcd
);

/* Set LCD refresh mode */
extern int screen_display_set_lcd_refresh
(
	screen_disp_set_lcd_refresh* set_lcd_refresh
);

/* Set LCD parameters */
extern int screen_display_set_lcd_if_parameters
(
	screen_disp_set_lcd_if_param* set_lcd_if_param
);

/* Start SDENC */
extern int screen_display_start_sdenc
(
	screen_disp_start_sdenc* start_sdenc
);

/* Stop SDENC */
extern int screen_display_stop_sdenc
(
	screen_disp_stop_sdenc* stop_sdenc
);

/* Set address  */
extern int screen_display_set_address
(
	screen_disp_set_address* address
);

/* Draw lcd blend*/
extern int screen_display_lcd_blend_draw
(
	screen_disp_lcd_blend_draw* lcd_blend_draw
);

/* Delete handle */
extern void screen_display_delete
(
	screen_disp_delete* disp_delete
);

#endif	/* __SCREEN_DISPLAY_H__ */
