/*
 * drivers/char/rtapi/include/screen_overlay.h
 *     This file is screen overlay function.
 *
 * Copyright (C) 2011 Renesas Electronics Corporation
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

#ifndef __SCREEN_OVERLAY_H__
#define __SCREEN_OVERLAY_H__

/****************************************/
/* Fixed Number				*/
/****************************************/
/* RT I/F Return code */
#define SMAP_LIB_OVERLAY_OK					(0)		/* Normality */
#define SMAP_LIB_OVERLAY_NG					(-1)	/* Others error */
#define SMAP_LIB_OVERLAY_PARAERR			(-2)	/* Parameter error */
#define SMAP_LIB_OVERLAY_SEQERR				(-3)	/* Sequence error */
#define SMAP_LIB_OVERLAY_MEMERR				(-4)	/* Memory allocate error */
#define SMAP_LIB_OVERLAY_INUSE				(-5)	/* Has already used it */

/* Overlay ID */
#define RT_OVERLAY_ID1						(1)		/* overlay id (1) */
#define RT_OVERLAY_ID2						(2)		/* overlay id (2) */
#define RT_OVERLAY_ID1A						(3)		/* overlay id (3) */
#define RT_OVERLAY_ID2A						(4)		/* overlay id (4) */

/* Overlay image Output */
#define RT_OVERLAY_LCD1						(1)
#define RT_OVERLAY_SDENC  					(3)

/* Image format */
#define RT_OVERLAY_COLOR_YUV420_SEMIPLANAR	(1)		/* YUV420 SemiPlanar */
#define RT_OVERLAY_COLOR_YUV420_PLANAR		(2)		/* YUV420 Planar */
#define RT_OVERLAY_COLOR_YUV422_SEMIPLANAR	(3)		/* YUV422 SemiPlanar */
#define RT_OVERLAY_COLOR_YUV422_PACKED		(4)		/* YUV422 Packed */
#define RT_OVERLAY_COLOR_RGB565			(5)		/* RGB565 */
#define RT_OVERLAY_COLOR_RGB888			(6)		/* RGB888 */
#define RT_OVERLAY_COLOR_ARGB8888		(7)		/* ARGB8888 */

/* YUV format */
#define RT_OVERLAY_COLOR_BT601				(1)		/* ITU-R BT.601 format */
#define RT_OVERLAY_COLOR_BT709				(2)		/* ITU-R BT.709 format */

/* YUV value range */
#define RT_OVERLAY_COLOR_COMPRESSED			(1)		/* YUV[16,235/240] */
#define RT_OVERLAY_COLOR_FULLSCALL			(2)		/* YUV[0:255] */

/* Rotation type */
#define RT_OVERLAY_ROTATE_0					(1)		/* Non-rotation */
#define RT_OVERLAY_ROTATE_90				(2)		/* Angle of 90 degrees */
#define RT_OVERLAY_ROTATE_180				(3)		/* Angle of 180 degrees */
#define RT_OVERLAY_ROTATE_270				(4)		/* Angle of 270 degrees */

/* Mirror type */
#define RT_OVERLAY_MIRROR_N					(1)		/* Non-inversion */
#define RT_OVERLAY_MIRROR_V					(2)		/* Up Down inversion */
#define RT_OVERLAY_MIRROR_H					(4)		/* Right Left inversion */

/* Notify type */
#define RT_OVERLAY_NOTIFY_RETURN			(1)		/* Notification of return code */
#define RT_OVERLAY_NOTIFY_ERROR_INFO		(2)		/* Notification of error */
#define RT_OVERLAY_NOTIFY_RETURN_BUFFER		(3)		/* Notification of image buffer refresh */

#define RT_OVERLAY_KEY_COLOR_OFF		(-1)		/* Key Color OFF */

/****************************************/
/* Structure				*/
/****************************************/

#ifndef _SCREEN_RECT_TYPE_
#define _SCREEN_RECT_TYPE_
typedef struct
{
	unsigned short x;
	unsigned short y;
	unsigned short width;
	unsigned short height;
} screen_rect;
#endif

typedef struct
{
	unsigned long user_data;
} screen_return_image_data;

typedef struct
{
	unsigned int err;
	int          debug_code;
} screen_error_info;

typedef struct
{
	unsigned int   command_type;
	unsigned short overlay_id;
	unsigned short dummy;
	union
	{
		screen_return_image_data return_buffer;
		screen_error_info        error_info;
	};
} screen_ovl_notify_return_data;

typedef struct
{
	void (*notify_overlay)
	(
		int                            result,
		screen_ovl_notify_return_data* notify_data,
		int                            data_size
	);
} screen_ovl_new;

typedef struct
{
	void*          handle;
	unsigned short overlay_id;
	unsigned short output_mode;
	unsigned short image_width;
	unsigned short image_height;
	unsigned short image_stride;
	unsigned short image_format;
	unsigned short yuv_format;
	unsigned short yuv_range;
} screen_ovl_initialize;

typedef struct
{
	void*           handle;
	unsigned short  overlay_id;
	unsigned short  dummy;
	screen_rect     src_crop;
	unsigned short  dst_width;
	unsigned short  dst_height;
	unsigned short  rotate;
	unsigned short  mirror;
	unsigned short  blend_pos_x;
	unsigned short  blend_pos_y;
	unsigned short  alpha;
	unsigned long   background_color;
	long 		key_color;
} screen_ovl_set_param;

typedef struct
{
	void*          handle;
	unsigned short overlay_id;
} screen_ovl_notify;

typedef struct
{
	void*          handle;
	unsigned short overlay_id;
	unsigned short dummy;
	unsigned char* image_address;
	unsigned long  image_size;
	void*          image_handle;
	unsigned long  user_data;
} screen_ovl_write_image;

typedef struct
{
	void*          handle;
	unsigned short overlay_id;
	unsigned short dummy;
} screen_ovl_quit;

typedef struct
{
	void* handle;
} screen_ovl_delete;

/****************************************/
/* function				*/
/****************************************/

/* Create handle */
extern void* screen_overlay_new
(
	screen_ovl_new* ovl_new
);

/* Initialize */
extern int screen_overlay_initialize
(
	screen_ovl_initialize* ovl_initialize
);

/* Set parameters */
extern int screen_overlay_set_parameters
(
	screen_ovl_set_param* ovl_set_param
);

/* Notification start */
extern int screen_overlay_start_notify
(
	screen_ovl_notify* ovl_notify
);

/* Write image */
extern int screen_overlay_write_image
(
	screen_ovl_write_image* ovl_write_image
);

/* Quit */
extern int screen_overlay_quit
(
	screen_ovl_quit* ovl_quit
);

/* Delete handle */
extern void screen_overlay_delete
(
	screen_ovl_delete* ovl_delete
);


#endif /* __SCREEN_OVERLAY_H__ */
