/*
 *  File Name       : RSPF0_spu_api_system.h
 *  Function        : SPU OPEN SOUND I/F
 *  Release Version : Ver 1.00
 *  Release Date    : 2011/11/30
 *
 *  Copyright (C) 2011 Renesas Electronics Corporation
 *
 *  This program is free software;you can redistribute it and/or modify it
 *  under the terms of the GNU General Public License as published by Free
 *  Softwere Foundation; either version 2 of License, or (at your option) any
 *  later version.
 *
 *  This program is distributed in the hope that it will be useful, but
 *  WITHOUT ANY WARRANTY;
 *  without even the implied warrnty of MERCHANTABILITY or FITNESS FOR A
 *  PARTICULAR PURPOSE.
 *  See the GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License along
 *  with this program;
 *  If not, write to the Free Software Foundation, Inc., 51 Franklin St,
 *  Fifth Floor, Boston, MA  02110-1301  USA
 *
 */
#ifndef __RSPF0_SPU_API_SYSTEM_H__
#define __RSPF0_SPU_API_SYSTEM_H__

enum {
	SPUAPI_SYSTEM_MEMORY_X = 0,
	SPUAPI_SYSTEM_MEMORY_Y = 1,
};

enum {
	SPUAPI_BUFFER_TYPE_WORD_RING   = 0,
	SPUAPI_BUFFER_TYPE_WORD_NORMAL = 1,
	SPUAPI_BUFFER_TYPE_BYTE        = 3,
};

enum {
	SPUAPI_LOG_CTRL_START = 0,
	SPUAPI_LOG_CTRL_STOP,
	SPUAPI_LOG_CTRL_RESET,
};

#define SPUAPI_BUFFER_TYPE_RING   SPUAPI_BUFFER_TYPE_WORD_RING
#define SPUAPI_BUFFER_TYPE_NORMAL SPUAPI_BUFFER_TYPE_WORD_NORMAL

typedef struct {
	unsigned long start_addr;
	unsigned long size;
	unsigned long error;
	struct {
		unsigned long free;
		unsigned long used;
		unsigned long max;
		unsigned long block;
	} heap;
	struct {
		unsigned long free;
		unsigned long used;
		unsigned long block;
	} aligned;
} sSPUMemoryStatus;

typedef struct {
	unsigned long count;
	unsigned long size;
	unsigned long addr;
	unsigned long rp;
	unsigned long wp;
} sSPUBufferStatus;

extern long SPUSystem_Init(unsigned long dsp_num);
extern long SPUSystem_GetVersion(unsigned long dsp_num, unsigned long *ver1,
							unsigned long *ver2);
/* API for buffer */
extern long SPUSystem_CreateBuffer(unsigned long dsp_num, unsigned long size,
					unsigned long type, sSPUBuffer *buffer);
extern long SPUSystem_DeleteBuffer(sSPUBuffer *buffer);
extern long SPUSystem_ResetBuffer(sSPUBuffer *buffer, unsigned long sync);
extern long SPUSystem_FlushBuffer(sSPUBuffer *buffer, unsigned long sync);
/* API for Debug */
extern long SPUSystem_GetBufferStatus(sSPUBuffer *buffer,
						sSPUBufferStatus *status);
extern long SPUSystem_GetMemoryStatus(unsigned long dsp_num,
			unsigned long memory_id, sSPUMemoryStatus *status);
extern long SPUSystem_GetModuleVersion(unsigned long dsp_num,
				unsigned long module_id, unsigned long *ver);
/* API for IO */
extern long SPUSystem_IoWrite(unsigned long dsp_num, unsigned long addr,
					unsigned long data, unsigned long sync);
extern long SPUSystem_IoRead(unsigned long dsp_num, unsigned long addr,
							unsigned long *data);

#endif /* __RSPF0_SPU_API_SYSTEM_H__ */

MODULE_LICENSE("GPL");
MODULE_DESCRIPTION("SPU OPEN SOUND I/F Ver 1.0");
MODULE_AUTHOR("Renesas Electronics");
